@@ -25,6 +25,10 @@ class FolderAlreadyExistsError(Error):
     pass
 
 
+class FolderNotWritableError(Error):
+    pass
+
+
 class CreateFolderError(Error):
     pass
 
@@ -53,5 +57,33 @@ class UnknownCommandError(Error):
     pass
 
 
-class SassError(Error):
+class ScssError(Error):
+    pass
+
+
+class WrongLoginCredentials(Error):
+    pass
+
+
+class GeneralError(Error):
+    pass
+
+
+class RemoteServerError(Error):
+    pass
+
+
+class NoExectuableError(Error):
+    pass
+
+
+class KeyNotAllowedError(Error):
+    pass
+
+
+class SubProjectError(Error):
+    pass
+
+
+class ParseError(Error):
     pass
